@@ -37,11 +37,11 @@ can be PCI-compliant.
 
 =head1 VERSION
 
-Version 1.2.0
+Version 1.2.2
 
 =cut
 
-our $VERSION = '1.2.0';
+our $VERSION = '1.2.2';
 
 our $SENSITIVE_ARGUMENT_NAMES = undef;
 our $SENSITIVE_REGEXP_PATTERNS = undef;
@@ -67,7 +67,7 @@ Here's an example of log4perl configuration that outputs a redacted trace
 To set your own list of arguments to redact, rather than use the defaults in C<Carp::Parse::Redact>,
 you need to set a localized version of $SENSITIVE_ARGUMENT_NAMES:
 
-	local $Log::Log4perl::Layout::PatternLayout::Redact::SENSITIVE_ARGUMENT_NAMES = 
+	$Log::Log4perl::Layout::PatternLayout::Redact::SENSITIVE_ARGUMENT_NAMES = 
 	[
 		'password',
 		'luggage_combination',
@@ -80,7 +80,7 @@ To set your own list of regexes to use for redaction, rather than use the
 defaults in C<Carp::Parse::Redact>, you need to set a localized version of
 $SENSITIVE_REGEXP_PATTERNS:
 
-	local $Log::Log4perl::Layout::PatternLayout::Redact::SENSITIVE_REGEXP_PATTERNS =
+	$Log::Log4perl::Layout::PatternLayout::Redact::SENSITIVE_REGEXP_PATTERNS =
 	[
 		qr/^\d{16}$/,
 	]
@@ -107,7 +107,7 @@ Here's an example of log4perl configuration that outputs a redacted message
 To redact the message, you will need to write your own redaction subroutine as
 follows:
 
-	local $Log::Log4perl::Layout::PatternLayout::Redact::MESSAGE_REDACTION_CALLBACK = sub
+	$Log::Log4perl::Layout::PatternLayout::Redact::MESSAGE_REDACTION_CALLBACK = sub
 	{
 		my ( $message ) = @_;
 		
@@ -249,10 +249,11 @@ and write code for them!
 
 Copyright 2012 Kate Kirby & Guillaume Aubert.
 
-This program is free software; you can redistribute it and/or modify it
-under the terms of the Artistic License.
+This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License version 3 as published by the Free Software Foundation.
 
-See http://dev.perl.org/licenses/ for more information.
+This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License along with this program. If not, see http://www.gnu.org/licenses/
 
 =cut
 
